###############################################################################
# UAGRA R Scripts                                           example_08_bats.R 
###############################################################################
# Body condition index vs. landscape metrics in R. ferrumequinum
###############################################################################
# Version: N/A
# Author:  prea@uninsubria.it
# created  20130820
# updated  20131101
###############################################################################
# 
#    Copyright (C) 2013  Damiano G. Preatoni
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    A copy of the GNU General Public License is available at 
#    http://www.gnu.org/licenses/gpl.txt, or can be requested to the Free
#    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#    Boston, MA 02110-1301 USA.
#
###############################################################################

## 1. prepare working environment

# clean up the workspace
rm(list=ls())

# we need some libraries:
library(foreign)   # read.csv, read.csv2
require(Hmisc)     # xYplot
require(lattice)   # lattice plots

# specify a 'working directory'
setwd('/data/Didattica/R/R_2013/src/data')

## 2. get data
# site data (direct input)
site.data <- data.frame(localita=c("Cormons","Pandona","S.Cesario","Toggiano"),
                        quota=c(58,140,56,600),
                        consistenza=c(190,360,30,26))
# read in bci data
bci.data <- read.csv2('BCI.csv', as.is=TRUE)
# read in landscape data
land.data <- read.csv('landscape.csv')



## 3. data conditioning

# condition some variable in bci.data
bci.data$localita <- factor(bci.data$localita,
                            levels=c('JAP', 'COR', 'SCP', 'TOG'),
                            labels=c('Pandona', 'Cormons', 'S.Cesario', 'Toggiano'))
bci.data$sesso <- factor(bci.data$sesso)
bci.data$eta <- factor(bci.data$eta)
# we need only female adults
bci.data <- bci.data[bci.data$sesso == 'f' & bci.data$eta == 'ad',]
# aggregate BCI by site
bci.avg <- aggregate(bci.data$BCI, by=list(bci.data$localita), FUN="mean")
names(bci.avg) <- c('localita','BCI.avg')
bci.sd <- aggregate(bci.data$BCI, by=list(bci.data$localita), FUN="sd")
names(bci.sd) <- c('localita','BCI.sd')
bci.avg <- merge(bci.avg, bci.sd, by="localita")
rm(bci.sd)
bci.avg <- merge(bci.avg, site.data, by="localita")
# now, dataframe bci.avg contains all average stats

# condition data in landscpe metrics data
land.data$localita <- factor(land.data$LID, levels=c(' D:\\w_rhifer\\uso_4 ',' D:\\w_rhifer\\uso_6 ',' D:\\w_rhifer\\uso_9 ','D:\\w_rhifer\\uso_11 '), labels=c('Pandona', 'Cormons', 'S.Cesario', 'Toggiano'))

# merge bci + landscape data
land <- merge(bci.avg, land.data,by="localita")
land$LID <- NULL # delete LID column


# 4. Exploratory Data Analysis

# BCI vs. elevation
xYplot(Cbind(BCI.avg,BCI.sd) ~ quota, groups=localita, bci.avg, type=c("p"), method="bars", ylim=c(.25,.4), label.curves=TRUE, auto.key=TRUE, ylab="BCI",xlab="Quota (m s.l.m.)")

cor.test(bci.avg$BCI.avg, bci.avg$quota


# BCI vs. colony size
xYplot(Cbind(BCI.avg,BCI.sd) ~ consistenza, groups=localita, bci.avg, type=c("p"), method="bars", ylim=c(.25,.4), label.curves=TRUE, auto.key=TRUE, ylab="BCI",xlab="Consistenza stimata della colonia (individui)")

cor.test(bci.avg$BCI.avg, bci.avg$consistenza)


# Automate correlation analysis between BCI and Landscape level metrics
# We need to repeat the same analysis for 70 variables!!

# get landscape variables names
land.vars <- names(land.data)[3:length(names(land.data))-1]

# define correlation tests 'limits'
corr.sig <- 0.06  # passes test if less than or equal to
corr.val <- 0.3   # passes test if greater then or equal to

land.vars.good <- vector() # to store interesting variable names

# open a 'sink file' to write tests results, but close it immediately
#  to avoid writing garbage into
sink(file='lansdcape_correlations.txt', split=TRUE)
sink()
         
# begin plotting & making correlations
for(v in land.vars) {
  filename <- paste("plots/land_BCI",v,"png",sep=".")
  cat("plotting",filename,"...")
  x <- land[[v]]
  c <- cor.test(land$BCI.avg,x)
  # a little data stashing to have a vector of 'interesting' variables
  if(!is.na(c$estimate)) {
    s <- paste("r=",formatC(c[["estimate"]],3),", p=",formatC(c[["p.value"]],3),sep="")
    sink(file='lansdcape_correlations.txt', split=TRUE, append=TRUE)    
    cat("correlation of", v, "with BCI", s, "\n")
    sink()
    if (abs(c[["estimate"]]) >= corr.val & c[["p.value"]] <= corr.sig) {
      land.vars.good <- c(land.vars.good, v)
      cat("SIGNIFICANT!")
    }
  } else {
    s <- "regression not possible"
  }
  plt <- xyplot(BCI.avg ~ x, land, type=c('p','r'), xlab=v, ylab="BCI", sub=s)
  #direct.label(plt)
  png(filename=filename)
  print(plt)
  dev.off()
  cat("\tDone.\n")
 }
sink()
rm(v,x,c,s,plt)

## End of File